package fr.velossity.sample.logging.backend;

import org.osgi.service.log.LogEntry;
import org.osgi.service.log.LogListener;
import org.osgi.service.log.LogReaderService;
import org.osgi.service.log.LogService;

import fr.velossity.twitter.Recipient;

/**
 * A simple LogListener which converts our platform logs in tweets.
 * 
 * @author C. Saint-Marcel
 * 
 */
public class Log2Twitter implements LogListener {

	/**
	 * iPOJO field. A recipient for our logs.
	 * 
	 */
	Recipient twitterUser;

	/**
	 * iPOJO field. Used to subscribe to the logs.
	 */
	LogReaderService logReader;

	/**
	 * iPOJO callback, called at activation.
	 */
	public void activate() {
		// Subscribe to logs
		logReader.addLogListener(this);
	}

	/**
	 * iPOJO callback, called at inactivation.
	 */
	public void inactivate() {
		// Do not forget to unsubscribe when inactivated
		logReader.removeLogListener(this);
	}

	/**
	 * The LogListener callback used to forward the logs to the Recipient
	 * service.
	 * 
	 * @see LogListener#logged(LogEntry)
	 */
	public void logged(LogEntry log) {
		if ((log.getBundle() == null)
				|| (log.getBundle().getSymbolicName() == null)) {
			// if there is no name, it's probably the framework emitting a log
			// This should not happen and we don't want to log something
			// anonymous
			return;
		}
		if ("org.apache.felix.framework".equals(log.getBundle()
				.getSymbolicName())) {
			// Do not log this
			return;
		}
		if ("TwitterService".equals(log.getBundle().getSymbolicName())) {
			// Do not log this to prevent from infinite loop
			return;
		}

		String message;
		// Deal with exception cases
		if (log.getException() != null) {
			message = log.getException().getMessage();
		} else {
			message = log.getMessage();
		}

		switch (log.getLevel()) {
			case LogService.LOG_DEBUG:
				twitterUser.sendMessage("DEBUG!" + message);
				break;
			case LogService.LOG_INFO:
				twitterUser.sendMessage("INFO!" + message);
				break;
			case LogService.LOG_WARNING:
				twitterUser.sendMessage("WARNING!" + message);
				break;
			case LogService.LOG_ERROR:
				twitterUser.sendMessage("ERROR!" + message);
				break;
		}
	}
}
